# Documentation

This directory contains detailed documentation for `torchresidual`.

## Files

- **[QUICKSTART.md](QUICKSTART.md)** - Get started in 5 minutes
- **[DESIGN.md](DESIGN.md)** - Technical design decisions and rationale
- **[FAQ.md](FAQ.md)** - Frequently asked questions

## Main Documentation

The primary documentation is in [../README.md](../README.md).

## Examples

See [../examples/](../examples/) for code examples.

## Contributing

See [../CONTRIBUTING.md](../CONTRIBUTING.md) for contribution guidelines.
